const express = require('express');
const app = express();
const http = require('http').Server(app);
const port = process.env.PORT || 3333;
const { Server } = require('socket.io');
const io = new Server(http);
const cookieParser = require('cookie-parser');

//database
const database = require(__dirname + '/db');
database.init();

//routes
const routes = require(__dirname + '/routes');

// session (used for login challenge)
const session = require('express-session');
const SQLiteStore = require('connect-sqlite3')(session);
const sessionMiddleware = session({
    store: new SQLiteStore,
    secret: process.env.COOKIE_SECRET || "toto",
    resave: false,
    saveUninitialized: true,
    cookie: { maxAge: 7 * 24 * 60 * 60 * 1000 } // 1 week
});

// configure app
app.set("port", port);
app.set('view engine', 'pug');
app.set('views', __dirname + '/views');
app.use(cookieParser());
app.use(express.json());
app.use(sessionMiddleware);

app.use("/", routes);
// bootstrap
app.use('/css', express.static(__dirname + '/node_modules/bootstrap/dist/css'));

// socket.io
io.engine.use(sessionMiddleware);
io.on('connection', (socket) => {
    const session = socket.request.session;
    console.log('A user connected');
    socket.on('disconnect', () => {
        console.log('User disconnected');
    });
    socket.on('chat message', (msg) => {
        console.log('message: ' + msg + ', sender: ' + session.id);
        console.log(session.publicKey);
    });
});


//start server
const server = http.listen(port, () => {
    console.log(`server is running on port ${server.address().port}`);
});
